@@ -37,32 +37,45 @@ summary.strel <- function(object, ...){
                                 as.data.frame(as.matrix(object$freq$conf$low)))
     out_matrix$int$up <- rbind(as.data.frame(as.matrix(object$Bayes$cred$up)),
                                as.data.frame(as.matrix(object$freq$conf$up)))
-    out_matrix$omega.freq.method <- object$omega.freq.method
+    out_matrix$omega.interval <- object$omega.interval
+    out_matrix$omega.pfa <- object$freq$omega.pfa
+    out_matrix$omega.error <- object$freq$omega.error
+    out_matrix$omega.item.error <- object$freq$omega.item.error
     out_matrix$n.iter <- object$n.iter
     out_matrix$n.burnin <- object$n.burnin
     out_matrix$n.boot <- object$n.boot
+    out_matrix$thin <- object$thin
+    out_matrix$n.chains <- object$n.chains
     out_matrix$ifitem$bay_est <- object$Bayes$ifitem$est
     out_matrix$ifitem$bay_cred <- object$Bayes$ifitem$cred
     out_matrix$ifitem$freq_tab <- object$freq$ifitem
+    out_matrix$para.boot <- object$para.boot
+    out_matrix$inv.mat <- object$freq$inv.mat
 
-  }
-  else if (!is.null(object$Bayes)) {
+  } else if (!is.null(object$Bayes)) {
     out_matrix$est <- as.data.frame(as.matrix(object$Bayes$est))
     out_matrix$int$low <- as.data.frame(as.matrix(object$Bayes$cred$low))
     out_matrix$int$up <- as.data.frame(as.matrix(object$Bayes$cred$up))
     out_matrix$n.iter <- object$n.iter
     out_matrix$n.burnin <- object$n.burnin
+    out_matrix$thin <- object$thin
+    out_matrix$n.chains <- object$n.chains
     out_matrix$ifitem$bay_est <- object$Bayes$ifitem$est
     out_matrix$ifitem$bay_cred <- object$Bayes$ifitem$cred
 
-  }
-  else if (!is.null(object$freq)) {
+  } else if (!is.null(object$freq)) {
     out_matrix$est <- as.data.frame(as.matrix(object$freq$est))
     out_matrix$int$low <- as.data.frame(as.matrix(object$freq$conf$low))
     out_matrix$int$up <- as.data.frame(as.matrix(object$freq$conf$up))
     out_matrix$n.boot <- object$n.boot
     out_matrix$ifitem$freq_tab <- object$freq$ifitem
-    out_matrix$omega.freq.method <- object$omega.freq.method
+    out_matrix$omega.interval <- object$omega.interval
+    out_matrix$omega.pfa <- object$freq$omega.pfa
+    out_matrix$omega.error <- object$freq$omega.error
+    out_matrix$omega.item.error <- object$freq$omega.item.error
+    out_matrix$para.boot <- object$para.boot
+    out_matrix$inv.mat <- object$freq$inv.mat
+
 
   } else {
     return(warning("no estimates calculated"))
@@ -97,39 +110,61 @@ print.summary.strel <- function(x, ...){
   cat("uncertainty interval: ")
   cat(x$interval, "\n")
 
-  if (!is.null(x$n.iter) & !is.null(x$n.burnin)) {
-    cat("iterations: ")
-    cat(x$n.iter, "\n")
-    cat("burnin: ")
-    cat(x$n.burnin, "\n")
-  }
+  # if (!is.null(x$n.iter) & !is.null(x$n.burnin)) {
+  #   cat("iterations: ")
+  #   cat(x$n.iter, "\n")
+  #   cat("burnin: ")
+  #   cat(x$n.burnin, "\n")
+  #   cat("thinning interval: ")
+  #   cat(x$thin, "\n")
+  #   cat("chains: ")
+  #   cat(x$n.chains, "\n")
+  # }
 
   if (length(grep("freq", x$est)) > 0) {
-    if (sum((c("alpha", "lambda2", "lambda6", "glb") %in% x$estimates)) > 0 |
-        ("omega" %in% x$estimates & x$omega.freq.method == "pfa")) {
-        cat("bootstrap samples: ")
-        cat(x$n.boot, "\n")
-      }
-    if ("omega" %in% x$estimates){
-      cat("frequentist omega method is: ")
-      cat(x$omega.freq.method, "\n")
-      cat("omega confidence interval is estimated with: ")
-      if (x$omega.freq.method == "pfa") {cat("bootstrap \n")}
-      if (x$omega.freq.method == "cfa") {cat("maximum likelihood z-value \n")}
-    }
-    # if (!is.null(x$fit.indices)){
-    #   options(scipen = 999)
-    #   cat("\nFrequentist fit of 1-factor-model for omega is:\n")
-    #   print.default(as.matrix(x$fit.indices))
+    # if (("alpha" %in% x$estimates & is.null(x$alpha.interval)) |
+    #     "lambda2" %in% x$estimates | "lambda4" %in% x$estimates | "lambda6" %in% x$estimates |
+    #     "glb" %in% x$estimates | ("omega" %in% x$estimates & !is.null(x$omega.pfa)) |
+    #     ("omega" %in% x$estimates & is.null(x$omega.interval))){
+    #     cat("bootstrap samples: ")
+    #     cat(x$n.boot, "\n")
     # }
+    # if ("alpha" %in% x$estimates & !is.null(x$alpha.interval)) {
+    #   cat("alpha confidence interval is estimated analytically \n")
+    # }
+    if (!is.null(x$inv.mat)) {
+      cat("the number of bootstrap samples reduced to ")
+      cat(x$inv.mat)
+      cat(" because some bootstrapped matrices were singular\n")
+    }
+    if ("omega" %in% x$estimates){
+      if (!is.null(x$omega.pfa) & !is.null(x$omega.error)) {
+        cat("frequentist omega method is pfa\n")
+        cat("omega confidence interval is estimated with bootstrap because the cfa did not find a solution\n")
+      }
+    }
+      # } else {
+      #   # cat("frequentist omega method: cfa ")
+      # }
+      # cat("\nomega confidence interval is estimated with: ")
+      # if (!is.null(x$omega.pfa)) {
+      #   cat("bootstrap \n")
+      # } else {
+      #   if (!is.null(x$omega.interval)) {
+      #     cat("maximum likelihood z-value \n")
+      #   } else {
+      #     cat("bootstrap \n")
+      #   }
+      # }
+
   }
 
   if (!is.null(x$complete)) {
-    cat("using listwise deletion the number of complete cases is: ")
+    cat("Missing data handling: using listwise deletion the number of complete cases is\n")
     cat(x$complete)
   }
   if (!is.null(x$pairwise)) {
-    cat("using pairwise complete cases")
+    cat("Missing data handling: using pairwise complete cases\n")
   }
 
 
@@ -160,8 +195,13 @@ print.summary.strel <- function(x, ...){
   if (!is.null(x$ifitem$freq_tab)){
       n_row <- length(unlist(x$ifitem$freq_tab[1])) + 1
       n_col <- length(x$estimates)
+      names <- NULL
+      for(z in 1:(n_row-1)){
+        names[z] <- paste0("x", z)
+      }
+      row_names <- c("original", names)
       mat_ifitem_freq <- data.frame(matrix(0, n_row, n_col))
-      mat_ifitem_freq[1, ] <- as.vector(unlist(x$est)[(n_col+1):(n_col*2)])
+      mat_ifitem_freq[1, ] <- as.vector(unlist(x$est)[grep("freq", rownames(x$est))])
       for (i in 1:n_col){
         mat_ifitem_freq[2:n_row, i] <- as.vector(unlist(x$ifitem$freq_tab[i]))
       }
@@ -171,6 +211,12 @@ print.summary.strel <- function(x, ...){
       cat("\n")
       cat("Frequentist point estimate if item dropped: \n")
       print(mat_ifitem_freq)
+
+      if ("omega" %in% x$estimates){
+        if (!is.null(x$omega.item.error)) {
+          cat("frequentist omega method for item.dropped statistic is pfa because the cfa did not find a solution\n")
+        }
+      }
   }
 
 }
